@@ -7,7 +7,7 @@ from ffast.preprocessor import PreprocessingPipeline
 PREPROCESSOR = PreprocessingPipeline()
 METAPHONES = "ABCEFHIJKLMNOPRSTUWXY0. "
 SIZE_METAPHONES = len(METAPHONES)
-PATH = "ffast/poincare/poincare.txt"
+PATH = "poincare/poincare.txt"
 raw_vocab = loadtxt(PATH,usecols=0,dtype=str)
 VOCABULARY = list(map(PREPROCESSOR.normalise,raw_vocab))
 VECTORS = loadtxt(PATH,usecols=range(1,101))
